==> trilinos_12.18.1.orig.tar.gz: Trilinos-trilinos-release-12-18-1/packages/panzer/disc-fe/src/evaluators/Panzer_FieldSpy_impl.hpp <==
// @HEADER
// ***********************************************************************
//
//           Panzer: A partial differential equation assembly
//       engine for strongly coupled complex multiphysics systems
//                 Copyright (2011) Sandia Corporation
//
// Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
// the U.S. Government retains certain rights in this software.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
// 1. Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
//
// 3. Neither the name of the Corporation nor the names of the
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY SANDIA CORPORATION "AS IS" AND ANY
// EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
// PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL SANDIA CORPORATION OR THE
// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
// PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
// LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
// NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
// Questions? Contact Roger P. Pawlowski (rppawlo@sandia.gov) and
// Eric C. Cyr (eccyr@sandia.gov)
// ***********************************************************************
// @HEADER

#ifndef __Panzer_FieldSpy_impl_hpp__
#define __Panzer_FieldSpy_impl_hpp__

#include <cmath>

#include "Phalanx_DataLayout_MDALayout.hpp"

#include "Panzer_Workset.hpp"

namespace panzer {

//**********************************************************************
template <typename EvalT,typename Traits>
FieldSpy<EvalT,Traits>::FieldSpy(const std::string & name,
                                 const Teuchos::RCP<PHX::DataLayout> & data_layout)
{
  using Teuchos::RCP;
  using Teuchos::rcp;

  dummyField = rcp(new PHX::Tag<ScalarT>("Field Spy: " + name,rcp(new PHX::MDALayout<panzer::Dummy>(0))));
  this->addEvaluatedField(*dummyField);

  source = PHX::MDField<const ScalarT,Cell,Point>(name, data_layout);
  this->addDependentField(source);
  
  std::string n = "Field Spy";
  this->setName(n);
}

//**********************************************************************
template <typename EvalT,typename Traits>
void FieldSpy<EvalT,Traits>::evaluateFields(typename Traits::EvalData workset)
{ 
  std::cout << "SPY: Name = \"" << source.fieldTag().identifier() << "\" at t = " << workset.time << "\n";
  for (index_t cell=0;cell<workset.num_cells;++cell) {
    std::cout << "SPY: ";
    for (int point = 0; point < source.extent_int(1); ++point) {
      std::cout << Sacado::ScalarValue<ScalarT>::eval(source(cell,point)) << " ";
    }
    std::cout << std::endl;
  }
}

//**********************************************************************
}

#endif

==> trilinos_16.1.0.orig.tar.gz: Trilinos-trilinos-release-16-1-0/packages/panzer/disc-fe/src/evaluators/Panzer_FieldSpy_impl.hpp <==
// @HEADER
// *****************************************************************************
//           Panzer: A partial differential equation assembly
//       engine for strongly coupled complex multiphysics systems
//
// Copyright 2011 NTESS and the Panzer contributors.
// SPDX-License-Identifier: BSD-3-Clause
// *****************************************************************************
// @HEADER

#ifndef __Panzer_FieldSpy_impl_hpp__
#define __Panzer_FieldSpy_impl_hpp__

#include <cmath>

#include "Phalanx_DataLayout_MDALayout.hpp"

#include "Panzer_Workset.hpp"

namespace panzer {

//**********************************************************************
template <typename EvalT,typename Traits>
FieldSpy<EvalT,Traits>::FieldSpy(const std::string & name,
                                 const Teuchos::RCP<PHX::DataLayout> & data_layout)
{
  using Teuchos::RCP;
  using Teuchos::rcp;

  dummyField = rcp(new PHX::Tag<ScalarT>("Field Spy: " + name,rcp(new PHX::MDALayout<panzer::Dummy>(0))));
  this->addEvaluatedField(*dummyField);

  source = PHX::MDField<const ScalarT,Cell,Point>(name, data_layout);
  this->addDependentField(source);
  
  std::string n = "Field Spy";
  this->setName(n);
}

//**********************************************************************
template <typename EvalT,typename Traits>
void FieldSpy<EvalT,Traits>::evaluateFields(typename Traits::EvalData workset)
{ 
  std::cout << "SPY: Name = \"" << source.fieldTag().identifier() << "\" at t = " << workset.time << "\n";
  for (index_t cell=0;cell<workset.num_cells;++cell) {
    std::cout << "SPY: ";
    for (int point = 0; point < source.extent_int(1); ++point) {
      std::cout << Sacado::scalarValue(source(cell,point)) << " ";
    }
    std::cout << std::endl;
  }
}

//**********************************************************************
}

#endif
